elf library

Classes

DynamicTable
The dynamic table, which contains entries pointing to various relocated addresses.
Elf
Information parsed from an Executable and Linking Format (ELF) file.
Section
A section in an ELF file.
Symbol
A symbol in an ELF file, which names a portion of the virtual address space.

Enums

DynamicTableTag
Represents d_tag constants from ELF specification.
SymbolBinding
An enumeration of recognized symbol binding values used by the ELF format.
SymbolType
An enumeration of recognized symbol types used by the ELF format.

Constants

dataSymbolName → const String
textSymbolName → const String