Symbol class

A symbol in an ELF file, which names a portion of the virtual address space.

Properties

bind → SymbolBinding?
no setter
hashCode → int
The hash code for this object.
no setterinherited
info → int
final
name ↔ String
latefinal
nameIndex → int
final
other → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionIndex → int
final
size → int
final
type → SymbolType?
no setter
value → int
final
visibility → SymbolVisibility?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
writeToStringBuffer(StringBuffer buffer) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromReader(Reader reader) → Symbol