SymbolBinding enum

An enumeration of recognized symbol binding values used by the ELF format.

Inheritance
Available extensions

Values

STB_LOCAL → const SymbolBinding
const SymbolBinding(0, 'local')
STB_GLOBAL → const SymbolBinding
const SymbolBinding(1, 'global')
STB_WEAK → const SymbolBinding
const SymbolBinding(2, 'weak')

Properties

code → int
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromCode(int code) → SymbolBinding?

Constants

values → const List<SymbolBinding>
A constant List of the values in this enum, in order of their declaration.