DynamicTable class

The dynamic table, which contains entries pointing to various relocated addresses.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
headerEntry SectionHeaderEntry
finalinherited
length int
no setterinherited
offset int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
virtualAddress int
no setterinherited

Methods

containsKey(DynamicTableTag tag) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shrink(Reader reader) → Reader
inherited
toString() String
A string representation of this object.
inherited
writeToStringBuffer(StringBuffer buffer) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](DynamicTableTag tag) int?

Static Methods

fromReader(Reader reader, SectionHeaderEntry entry) DynamicTable
override